# frozen_string_literal: true

User.class_eval do
  field :main_applicant_id, type: BSON::ObjectId
  field :reservation_holder_id, type: BSON::ObjectId
  field :lessor_id, type: BSON::ObjectId

  after_save :hermes_after_actions

  def main_applicant
    Hermes::Applicant.find_by(id: main_applicant_id)
  end

  def reservation_holder
    Hermes::ReservationHolder.find(reservation_holder_id)
  end

  def lessor
    Hermes::Lessor.find(lessor_id)
  rescue
    nil
  end

  def lessor=(les)
    self.lessor_id = les.id
  end

  def has_lessor?
    lessor_id.present?
  end

  def hermes_after_actions
    update_main_applicant_name if name_changed?
    update_main_applicant_email if email_changed?
    main_applicant.save if main_applicant_will_move?
  end

  def name_changed?
    first_name_changed? || last_name_changed?
  end

  def update_main_applicant_name
    main_applicant&.name_will_change = true
  end

  def update_main_applicant_email
    main_applicant&.email_will_change = true
  end

  def main_applicant_will_move?
    main_applicant&.name_will_change || main_applicant&.email_will_change
  end
end
